@@ -8,6 +8,8 @@ import re
 import unicodedata
 from typing import Any, Iterable, List, Optional, Union
 
+from wcwidth import wcswidth
+
 from . import constants
 
 
@@ -20,6 +22,16 @@ def strip_ansi(text: str) -> str:
     return constants.ANSI_ESCAPE_RE.sub('', text)
 
 
+def ansi_safe_wcswidth(text: str) -> int:
+    """
+    Wraps wcswidth to make it compatible with colored strings
+
+    :param text: the string being measured
+    """
+    # Strip ANSI escape codes since they cause wcswidth to return -1
+    return wcswidth(strip_ansi(text))
+
+
 def is_quoted(arg: str) -> bool:
     """
     Checks if a string is quoted
